# primalhelper

## Description

A selection of tools for wrangling PrimerSchemes

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)


## Installation

Install via poetry

```
git clone https://github.com/ChrisgKent/primalhelper
cd primalhelper 
poetry install
```

## Usage


See commands

```poetry run primalhelper --help```

#### Convert bedfiles

```poetry run primalhelper legacy --bedfile {path} > primer.bed```



